deviceconfig - Faraday Flash Configuration Tool
======================================

The deviceconfig Faraday Python module contains class objects and function(s) that help create a flash configuration packet payload to update the Faraday non-volatile configuration.

.. automodule:: deviceconfig
    :members:
